@@ -2,6 +2,8 @@
 
 use strict;
 
+use FindBin qw($Bin);
+
 use Rose::DB;
 
 BEGIN 
@@ -129,7 +131,38 @@ BEGIN
     password => '',
   );
 
-  my @types = qw(pg pg_with_schema pg_admin mysql mysql_admin informix informix_admin);
+  #
+  # SQLite
+  #
+
+  eval { require DBD::SQLite };
+  
+  my $version = $DBD::SQLite::VERSION || 0;
+
+  unless($ENV{'RDBO_NO_SQLITE'} || $version < 1.08)
+  {
+    # Main
+    Rose::DB->register_db(
+      domain   => 'test',
+      type     => 'sqlite',
+      driver   => 'sqlite',
+      database => "$Bin/sqlite.db",
+      auto_create     => 0,
+      connect_options => { AutoCommit => 1 },
+    );
+  
+    # Admin
+    Rose::DB->register_db(
+      domain   => 'test',
+      type     => 'sqlite_admin',
+      driver   => 'sqlite',
+      database => "$Bin/sqlite.db",
+      connect_options => { AutoCommit => 1 },
+    );
+  }
+
+  my @types = qw(pg pg_with_schema pg_admin mysql mysql_admin 
+                 informix informix_admin sqlite sqlite_admin);
 
   unless($Rose::DB::Object::Test::NoDefaults)
   {
@@ -162,6 +195,8 @@ BEGIN
   }
 }
 
+Rose::DB->load_driver_classes(qw(pg MySQL informix SQLItE));
+  
 # Subclass testing
 package My::DB;
 @My::DB::ISA = qw(Rose::DB);
